pub struct RootConfig {
pub protocols: ProtocolConfig,
pub provider: ProviderConfig,
pub registries: HashMap<String, RegistryConfig>,
pub data: HashMap<String, String>,
}Expand description
used to storage all structed config, from some source: cmd, file..; Impl Config trait, business init by read Config trait
Fields
protocols: ProtocolConfigprovider: ProviderConfigregistries: HashMap<String, RegistryConfig>data: HashMap<String, String>Implementations